@@ -19,7 +19,7 @@ class KAddressBookPart : public KParts::Part
     Q_OBJECT
 
 public:
-    explicit KAddressBookPart(QWidget *parentWidget, QObject *parent, const QVariantList &);
+    explicit KAddressBookPart(QWidget *parentWidget, QObject *parent, const KPluginMetaData &data, const QVariantList &);
     ~KAddressBookPart() override;
 
 public Q_SLOTS:
